---
name: Bug report
about: Create a report to help us improve
title: ''
labels: new
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Execution environment**
List the OS, python version, system environment variables, etc.

**Pip Packages**
If python related run `python -m pip list` and copy the output here

**Additional context**
Add any other context about the problem here.
